"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.createCellsRouter = void 0;
const express_1 = __importDefault(require("express"));
const fs_1 = __importDefault(require("fs"));
const path_1 = __importDefault(require("path"));
function isLocalApiError(err) {
    return typeof err.code === 'string';
}
const createCellsRouter = (filename, dir) => {
    const router = express_1.default.Router();
    router.use(express_1.default.json());
    const fullPath = path_1.default.join(dir, filename);
    router.get('/cells', (req, res) => __awaiter(void 0, void 0, void 0, function* () {
        let data;
        try {
            const result = fs_1.default.readFileSync(fullPath, { encoding: 'utf-8' });
            data = JSON.parse(result);
        }
        catch (err) {
            if (isLocalApiError(err)) {
                if (err.code === 'ENOENT') {
                    fs_1.default.writeFileSync(fullPath, '[]', 'utf-8');
                    data = [];
                }
            }
            else {
                if (err instanceof Error)
                    res.status(500).send({ error: err.message });
                throw err;
            }
        }
        res.send(data);
    }));
    router.post('/cells', (req, res) => __awaiter(void 0, void 0, void 0, function* () {
        const { cells } = req.body;
        try {
            yield fs_1.default.writeFileSync(fullPath, JSON.stringify(cells), 'utf-8');
            res.send({ status: 'ok' });
        }
        catch (err) {
            console.log(err);
        }
    }));
    return router;
};
exports.createCellsRouter = createCellsRouter;
